@@ -1,8 +1,18 @@
+# Copyright (c) 2016, The Regents of the University of California.
+
 from __future__ import absolute_import
-from . import DBConstants
-import os
-import sqlite3
+
+import argparse
 import itertools
+import os
+try:
+    import sqlite3
+except ImportError:
+    pass
+import itertools
+import sys
+
+from . import DBConstants, fasta, fastq, openscreed
 
 
 def create_db(filepath, fields, rcrditer):
@@ -12,6 +22,12 @@ def create_db(filepath, fields, rcrditer):
     record. rcrditer is an iterator returning records over a
     sequence dataset. Records yielded are in dictionary form
     """
+    try:
+        sqlite3
+    except NameError:
+        raise Exception("error: sqlite3 is needed for this functionality" +
+                        " but is not installed.")
+
     if not filepath.endswith(DBConstants.fileExtension):
         filepath += DBConstants.fileExtension
 
@@ -81,3 +97,34 @@ def create_db(filepath, fields, rcrditer):
 
     con.commit()
     con.close()
+
+
+def make_db(filename):
+    iterfunc = openscreed.Open(filename, parse_description=True)
+
+    field_mapping = {
+        fastq.fastq_iter.__name__: fastq.FieldTypes,
+        fasta.fasta_iter.__name__: fasta.FieldTypes
+    }
+
+    fieldTypes = field_mapping[iterfunc.iter_fn.__name__]
+
+    # Create the screed db
+    create_db(filename, fieldTypes, iterfunc)
+
+
+def main(args):
+    parser = argparse.ArgumentParser(description="A shell interface to the "
+                                     "screed database writing function")
+    parser.add_argument('filename')
+    args = parser.parse_args(args)
+
+    make_db(args.filename)
+
+    print("Database saved in {}{}".format(args.filename,
+                                          DBConstants.fileExtension))
+    exit(0)
+
+
+if __name__ == "__main__":
+    main(sys.argv[1:])
