@@ -1,7 +1,8 @@
-from __future__ import absolute_import
+# Copyright (c) 2016, The Regents of the University of California.
 
+from __future__ import absolute_import
 from . import DBConstants
-from .screedRecord import Record, _Writer
+from .screedRecord import Record
 from .utils import to_str
 
 FieldTypes = (('name', DBConstants._INDEXED_TEXT_KEY),
@@ -19,7 +20,7 @@ def fastq_iter(handle, line=None, parse_description=False):
         line = handle.readline()
     line = to_str(line.strip())
     while line:
-        data = Record()
+        data = {}
 
         if line and not line.startswith('@'):
             raise IOError("Bad FASTQ format: no '@' at beginning of line")
@@ -60,12 +61,4 @@ def fastq_iter(handle, line=None, parse_description=False):
             raise IOError('sequence and quality strings must be '
                           'of equal length')
 
-        yield data
-
-
-class FASTQ_Writer(_Writer):
-
-    def write(self, record):
-        s = "@%s %s\n%s\n+\n%s\n" % (record.name, record.description,
-                                     record.sequence, record.quality)
-        self.fp.write(s)
+        yield Record(**data)
