@@ -1,4 +1,7 @@
 # Copyright (c) 2008-2015, Michigan State University
+"""
+Test `screed.open`.
+"""
 
 from __future__ import absolute_import
 
@@ -90,16 +93,6 @@ def test_gz_open_fastq():
     assert n > 0
 
 
-def test_get_writer_class_fasta():
-    import screed.fasta
-
-    filename = utils.get_test_data('test.fa')
-
-    read_iter = screed.open(filename)
-    x = screed.openscreed.get_writer_class(read_iter)
-    assert x is screed.fasta.FASTA_Writer, x
-
-
 def test_unknown_fileformat():
 
     try:
